# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2018-03-17 17:51
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0003_auto_20180301_0202'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='part',
            unique_together=set([('number_class', 'number_item', 'number_variation', 'organization')]),
        ),
    ]
